#!/bin/bash
# -*- coding: utf-8 -*-

ppp_dir="/var"
pppif_host_script=/opt/bin/pppif_host_cfg.py

function setup_ppp_if() {
  ifname=$1
  filename=$2
  dnsopts=""
  dnslist=""

  iplocal=`cat $filename | grep "^IPLOCAL=" | cut -f2 -d "="`
  ipremote=`cat $filename | grep "^IPREMOTE=" | cut -f2 -d "="`
  userpeerdns=`cat $filename | grep "^USEPEERDNS=" | cut -f2 -d "="`
  dns1=`cat $filename | grep "^DNS1=" | cut -f2 -d "="`
  dns2=`cat $filename | grep "^DNS2=" | cut -f2 -d "="`

  # logger -t ppp_if "userpeerdns - $userpeerdns dns1  - $dns1 dns2 - $dns2 iplocal - $iplocal ipremote - $ipremote"
  if [ ! -z "${dns1}" ]; then
    dnsopts="--set-dns ${dns1}"
    dnslist="${dns1}"
  fi

  if [ ! -z "${dns2}" ] && [ "${dns1}" != "${dns2}" ]; then
    dnsopts+=" --set-dns ${dns2}"
    dnslist+=",${dns2}"
  fi
  if [ ! -z "${dnsopts}" ] && [ "${dnsopts}" != "" ]; then
    resolvectl ${dnsopts} --interface=${ifname}
    logger -t ppp_if "DNS configuration applied for PPPoE interface $ifname"
  fi
  if [ ! -z "${ipremote}" ] && [ ! -z "${iplocal}" ]; then
    logger -t ppp_if "Apply NAT / IP-Passthrough for PPPoE interface $ifname"
    if [ -f $pppif_host_script ]; then
      $pppif_host_script -n ${ifname} -l ${iplocal} -r ${ipremote} --ldns ${dnslist} &
    fi
  fi
}

function delete_ppp_if() {
  ifname=$1
  filename=$2
  
  iplocal=`cat $filename | grep "^IPLOCAL=" | cut -f2 -d "="`
  ipremote=`cat $filename | grep "^IPREMOTE=" | cut -f2 -d "="`
  userpeerdns=`cat $filename | grep "^USEPEERDNS=" | cut -f2 -d "="`
  dns1=`cat $filename | grep "^DNS1=" | cut -f2 -d "="`
  dns2=`cat $filename | grep "^DNS2=" | cut -f2 -d "="`

  # logger -t ppp_if "userpeerdns - $userpeerdns dns1  - $dns1 dns2 - $dns2 iplocal - $iplocal ipremote - $ipremote"

  if [ "${userpeerdns}" == "1" ]; then
    resolvectl --interface=${ifname} --revert
    logger -t ppp_if "DNS configuration cleared for PPPoE interface $ifname"
  fi

  if [ ! -z "${ipremote}" ] && [ ! -z "${iplocal}" ]; then
    logger -t ppp_if "Check fot NAT / IP-Passthrough configuration for PPPoE interface $ifname"
    if [ -f $pppif_host_script ]; then
      $pppif_host_script -n ${ifname} -l ${iplocal} -r ${ipremote} -d &
    fi
  fi

  rm $filename
}

if [ "$#" -lt 2 ]; then
    logger -t ppp_if "Need at least two arguments. Exiting..."
    exit 1
fi

filename="$ppp_dir/$1-vars"
if [ ! -f "$filename" ]; then
    logger -t ppp_if "File $filename doesn't exists. Exiting..."
    exit 1
fi

case "$2" in
  up)
    setup_ppp_if $1 $filename
    ;;
  down)
    delete_ppp_if $1 $filename
    ;;
  *)
    logger -t ppp_if "Unknown operation. Exiting..."
    exit 1
    ;;
esac

logger -t ppp_if "Exit.."
exit 0

