#! /usr/bin/env python3
import os
import sys
import argparse
import subprocess
import sysrepo_interfaces.sysrepo_interfaces3 as sri

def get_if_name(ifname):
	if ifname.startswith('br-'):
		return str(ifname.replace('br-',''))
	
	return ifname

def ippass_permit_host(args):
	inft_cfg = sri.SysrepoInterfaces(app_name='vpp-ippass-dhcp')
	ifname = get_if_name(args.ifname)

	if inft_cfg.get_interface_param(ifname, 'ip-passthrough') != True:
		sys.exit(0)
	
	# if inft_cfg.get_interface_param(ifname, 'management') != True:
	# 	sys.exit(0)
	inft_cfg.ippass_add_del_management_entries(ifname, args.ip_addr, args.delete)
	sys.exit(0)

def is_active(svc):
	try:
		state = subprocess.check_output(['systemctl', 'is-active', svc ])
		if state.decode().rstrip() == 'active':
			return True
	except subprocess.CalledProcessError as e:
		if e.output.decode().rstrip() == 'active':
			return True

	return False

if __name__ == "__main__":

	if is_active('vpp-config.service') == False:
		sys.exit(0)

	parser = argparse.ArgumentParser()
	subparsers = parser.add_subparsers(help='sub-command help')

	parser_arp = subparsers.add_parser('ippass_permit_host', help='Permit incoming traffic to interface')
	parser_arp.add_argument('--ip-addr', type=str, required=True, help='IP Address')
	parser_arp.add_argument('--ifname', type=str, required=True, help='Interface name')
	parser_arp.add_argument('--delete', action='store_false', help='Remove entry')
	parser_arp.set_defaults(func=ippass_permit_host)

	args = parser.parse_args()
	args.func(args)

	sys.exit(0)
