#! /usr/bin/env python3
import os
import sys
import argparse
import subprocess
import vppapi_if.vppapi_if as vpp_if
from tveif import if_lte


LTE_OFFSET=100

def check_lte(ifname):
	# if not ifname.startswith('lte'):
	if 'lte' not in ifname:
		return False
	if not os.path.exists('/sys/class/net/{}'.format(ifname)):
		print('Interface {}, does not exist. Skip ARP term config!'.format(ifname))
		return False

	return True


def get_lte_if_name(ifname):
	if ifname.startswith('br-'):
		return str(ifname.replace('br-',''))

	return ifname

def add_arp_term_entry(ifname, ip_addr,flush=False):
	lte_id = int(ifname.replace('lte',''))

	taplte = vppif.get_tap_interface_by_id(id=lte_id+LTE_OFFSET)
	bd_id=taplte['sw_if_index']

	hostlte = vppif.get_if_by_name('host-'+ifname)
	mac_addr=hostlte.get('mac_addr', '00:00:00:A1:00:00')

	if flush is True:
		vppif.flush_bd_ip_mac_entries(bd_id=bd_id)

	vppif.add_bd_ip_mac_entry(bd_id=bd_id, ip=ip_addr, mac=mac_addr)
	vppif.set_bd_arp_term(bd_id=bd_id)

def arp_handler(args):
	ifname = get_lte_if_name(args.ifname)

	if not check_lte(ifname):
		sys.exit(0)

	if not if_lte.lte_check_raw_if(ifname):
		print('Interface {}, is not RAW IP. Skip ARP term config!'.format(ifname))
		sys.exit(0)

	add_arp_term_entry(ifname=ifname, ip_addr=args.ip_addr, flush=args.flush_table)

def lte_hotplug(args):
	ifname = get_lte_if_name(args.ifname)
	if not check_lte(ifname):
		sys.exit(1)

def get_network_mode():

	net_mode = subprocess.check_output(['sysrepocfg', '-X', '-x', '/ucpe:config/system:system/network-mode', '-f', 'json', '-d',
										'startup']).decode("utf-8")
	if net_mode.find('"network-mode": "vpp"') > -1:
		return "vpp"

	return "ovs"


if __name__ == "__main__":

	if get_network_mode() != 'vpp':
		sys.exit(0)

	vppif = vpp_if.VppApiInterface('LTE config handler')

	parser = argparse.ArgumentParser()
	subparsers = parser.add_subparsers(help='sub-command help')

	parser_arp = subparsers.add_parser('arp_handler', help='ARP handler configuration')
	parser_arp.add_argument('--ip-addr', type=str, required=True, help='IP Address')
	parser_arp.add_argument('--ifname', type=str, required=True, help='Interface name')
	parser_arp.add_argument('--flush-table', action='store_true', help='Remove all old entries and then add the new one')
	parser_arp.set_defaults(func=arp_handler)

	parser_hotplug = subparsers.add_parser('hotplug', help='Hotplug LTE interface')
	parser_hotplug.add_argument('--ifname', type=str, required=True, help='Interface name')
	parser_hotplug.set_defaults(func=lte_hotplug)
	args = parser.parse_args()
	args.func(args)

	sys.exit(0)
